@@ -26,7 +26,7 @@ from metaphor.models.metadata_change_event import (
     EntityType,
 )
 
-logger = get_logger(__name__)
+logger = get_logger()
 
 
 class BigQueryLineageExtractor(BaseExtractor):
