@@ -45,11 +45,12 @@ from metaphor.snowflake.utils import (
     QueryWithParam,
     SnowflakeTableType,
     async_execute,
+    check_access_history,
     exclude_username_clause,
     fetch_query_history_count,
 )
 
-logger = get_logger(__name__)
+logger = get_logger()
 
 # Filter out "Snowflake" database & all "information_schema" schemas
 DEFAULT_FILTER: DatabaseFilter = DatasetFilter(
@@ -363,17 +364,44 @@ class SnowflakeExtractor(BaseExtractor):
         start_date = start_of_day(self._query_log_lookback_days)
         end_date = start_of_day()
 
+        has_access_history = check_access_history(self._conn)
+        logger.info(f"Using Snowflake Enterprise edition: {has_access_history}")
+
         count = fetch_query_history_count(
-            self._conn, start_date, self._query_log_excluded_usernames, end_date
+            self._conn,
+            start_date,
+            self._query_log_excluded_usernames,
+            end_date,
+            has_access_history,
         )
         batches = math.ceil(count / self._query_log_fetch_size)
         logger.info(f"Total {count} queries, dividing into {batches} batches")
 
-        queries = {
+        queries = (
+            self._batch_query_for_access_logs(start_date, end_date, batches)
+            if has_access_history
+            else self._batch_query_for_query_logs(start_date, end_date, batches)
+        )
+
+        async_execute(
+            self._conn,
+            queries,
+            "fetch_query_logs",
+            self._max_concurrency,
+            self._parse_query_logs,
+        )
+
+        logger.info(f"Fetched {len(self._logs)} query logs")
+
+    def _batch_query_for_access_logs(
+        self, start_date: datetime, end_date: datetime, batches: int
+    ):
+        return {
             x: QueryWithParam(
                 f"""
                 SELECT q.QUERY_ID, q.USER_NAME, QUERY_TEXT, START_TIME, TOTAL_ELAPSED_TIME, CREDITS_USED_CLOUD_SERVICES,
-                  BYTES_SCANNED, BYTES_WRITTEN, ROWS_PRODUCED, DIRECT_OBJECTS_ACCESSED, OBJECTS_MODIFIED
+                  DATABASE_NAME, SCHEMA_NAME, BYTES_SCANNED, BYTES_WRITTEN, ROWS_PRODUCED,
+                  DIRECT_OBJECTS_ACCESSED, OBJECTS_MODIFIED
                 FROM SNOWFLAKE.ACCOUNT_USAGE.QUERY_HISTORY q
                 JOIN SNOWFLAKE.ACCOUNT_USAGE.ACCESS_HISTORY a
                   ON a.QUERY_ID = q.QUERY_ID
@@ -395,18 +423,34 @@ class SnowflakeExtractor(BaseExtractor):
             )
             for x in range(batches)
         }
-        async_execute(
-            self._conn,
-            queries,
-            "fetch_query_logs",
-            self._max_concurrency,
-            self._parse_access_logs,
-        )
 
-        logger.info(f"Fetched {len(self._logs)} query logs")
+    def _batch_query_for_query_logs(
+        self, start_date: datetime, end_date: datetime, batches: int
+    ):
+        return {
+            x: QueryWithParam(
+                f"""
+                SELECT QUERY_ID, USER_NAME, QUERY_TEXT, START_TIME, TOTAL_ELAPSED_TIME, CREDITS_USED_CLOUD_SERVICES,
+                  DATABASE_NAME, SCHEMA_NAME, BYTES_SCANNED, BYTES_WRITTEN, ROWS_PRODUCED
+                FROM SNOWFLAKE.ACCOUNT_USAGE.QUERY_HISTORY
+                WHERE EXECUTION_STATUS = 'SUCCESS'
+                  AND START_TIME > %s AND START_TIME <= %s
+                  {exclude_username_clause(self._query_log_excluded_usernames)}
+                ORDER BY QUERY_ID
+                LIMIT {self._query_log_fetch_size} OFFSET %s
+                """,
+                (
+                    start_date,
+                    end_date,
+                    *self._query_log_excluded_usernames,
+                    x * self._query_log_fetch_size,
+                ),
+            )
+            for x in range(batches)
+        }
 
-    def _parse_access_logs(self, batch_number: str, access_logs: List[Tuple]) -> None:
-        logger.info(f"access logs batch #{batch_number}")
+    def _parse_query_logs(self, batch_number: str, query_logs: List[Tuple]) -> None:
+        logger.info(f"query logs batch #{batch_number}")
         for (
             query_id,
             username,
@@ -414,15 +458,24 @@ class SnowflakeExtractor(BaseExtractor):
             start_time,
             elapsed_time,
             credit,
+            default_database,
+            default_schema,
             bytes_scanned,
             bytes_written,
             rows_produced,
-            accessed_objects,
-            modified_objects,
-        ) in access_logs:
+            *access_objects,
+        ) in query_logs:
             try:
-                sources = self._parse_accessed_objects(accessed_objects)
-                targets = self._parse_accessed_objects(modified_objects)
+                sources = (
+                    self._parse_accessed_objects(access_objects[0])
+                    if len(access_objects) == 2
+                    else None
+                )
+                targets = (
+                    self._parse_accessed_objects(access_objects[1])
+                    if len(access_objects) == 2
+                    else None
+                )
 
                 query_log = QueryLog(
                     id=f"{DataPlatform.SNOWFLAKE.name}:{query_id}",
@@ -433,6 +486,8 @@ class SnowflakeExtractor(BaseExtractor):
                     duration=float(elapsed_time / 1000.0),
                     cost=float(credit) if credit else None,
                     user_id=username,
+                    default_database=default_database,
+                    default_schema=default_schema,
                     rows_written=float(rows_produced) if rows_produced else None,
                     bytes_read=float(bytes_scanned) if bytes_scanned else None,
                     bytes_written=float(bytes_written) if bytes_written else None,
@@ -444,7 +499,7 @@ class SnowflakeExtractor(BaseExtractor):
 
                 self._logs.append(query_log)
             except Exception:
-                logger.exception(f"access log processing error, query id: {query_id}")
+                logger.exception(f"query log processing error, query id: {query_id}")
 
     @staticmethod
     def _build_tag_string(tag_key: str, tag_value: str) -> str:
