@@ -100,35 +100,71 @@ def exclude_username_clause(excluded_usernames: Set[str]) -> str:
     )
 
 
+def check_access_history(
+    conn: SnowflakeConnection,
+) -> bool:
+    """
+    Check if access history table is available
+    """
+    cursor = conn.cursor()
+    cursor.execute(
+        """
+        SELECT QUERY_ID
+        FROM SNOWFLAKE.ACCOUNT_USAGE.ACCESS_HISTORY
+        LIMIT 1
+        """
+    )
+    result = cursor.fetchall()
+    return len(result) > 0
+
+
 def fetch_query_history_count(
     conn: SnowflakeConnection,
     start_date: datetime,
     excluded_usernames: Set[str],
     end_date: datetime = datetime.now(),
+    has_access_history: bool = True,
 ) -> int:
     """
     Fetch query history count
     """
     cursor = conn.cursor()
-    cursor.execute(
-        f"""
-        SELECT COUNT(1)
-        FROM SNOWFLAKE.ACCOUNT_USAGE.QUERY_HISTORY q
-        JOIN SNOWFLAKE.ACCOUNT_USAGE.ACCESS_HISTORY a
-          ON a.QUERY_ID = q.QUERY_ID
-        WHERE EXECUTION_STATUS = 'SUCCESS'
-          and START_TIME > %s and START_TIME <= %s
-          and QUERY_START_TIME > %s AND QUERY_START_TIME <= %s
-          {exclude_username_clause(excluded_usernames)}
-        """,
-        (
-            start_date,
-            end_date,
-            start_date,
-            end_date,
-            *excluded_usernames,
-        ),
-    )
+    if has_access_history:
+        cursor.execute(
+            f"""
+            SELECT COUNT(1)
+            FROM SNOWFLAKE.ACCOUNT_USAGE.QUERY_HISTORY q
+            JOIN SNOWFLAKE.ACCOUNT_USAGE.ACCESS_HISTORY a
+              ON a.QUERY_ID = q.QUERY_ID
+            WHERE EXECUTION_STATUS = 'SUCCESS'
+              and START_TIME > %s and START_TIME <= %s
+              and QUERY_START_TIME > %s AND QUERY_START_TIME <= %s
+              {exclude_username_clause(excluded_usernames)}
+            """,
+            (
+                start_date,
+                end_date,
+                start_date,
+                end_date,
+                *excluded_usernames,
+            ),
+        )
+    else:
+        cursor.execute(
+            f"""
+                    SELECT COUNT(1)
+                    FROM SNOWFLAKE.ACCOUNT_USAGE.QUERY_HISTORY q
+                    WHERE EXECUTION_STATUS = 'SUCCESS'
+                      and START_TIME > %s and START_TIME <= %s
+                      {exclude_username_clause(excluded_usernames)}
+                    """,
+            (
+                start_date,
+                end_date,
+                *excluded_usernames,
+            ),
+        )
+
     result = cursor.fetchone()
     if result is not None:
         return result[0]
